#!/usr/bin/env python3
import sys
import time

import pandas as pd
import biogeme . database as db
import biogeme . biogeme as bio
import biogeme . models as models
import biogeme.distributions as dist
import biogeme . optimization as opt
import biogeme.messaging as msg
from biogeme.expressions import Beta, DefineVariable, bioDraws, log, MonteCarlo, RandomVariable, Integrate, exp

file_to_open = sys.argv[1]
df = pd.read_csv(file_to_open, sep=';')
database = db.Database('example', df)
globals().update(database.variables)

exclude = (V2017 <= 0)
database.remove(exclude)

ASC_IWT = Beta ('ASC_IWT' ,0,None ,None ,1)
ASC_ROAD = Beta ('ASC_ROAD' ,0,None ,None ,0)
ASC_RAIL = Beta ('ASC_RAIL' ,0,None ,None ,0)
B_COST = Beta ('B_COST' ,0,None ,None ,0)
B_FREQ = Beta ('B_FREQ' ,0,None ,None ,0)
B_PORT = Beta ('B_PORT' ,0,None ,None ,0)
B_COST_ROAD = Beta ('B_COST_ROAD' ,0,None ,None ,0)
B_COST_INTER = Beta ('B_COST_INTER' ,0,None ,None ,0)
B_ACCESS_ROAD = Beta ('B_ACCESS_ROAD' ,0,None ,None ,0)
B_ACCESS_INTER = Beta ('B_ACCESS_INTER' ,0,None ,None ,0)
B_COST_INTER_S = Beta('B_COST_INTER_S', 1, None, None, 0)
B_COST_INTER_RND = -exp(B_COST_INTER + B_COST_INTER_S * bioDraws('B_COST_INTER_RND', 'NORMAL'))

C_ROAD = C_ROAD_POCK/1000
C_RAIL = C_RAIL_INTER_POCK/1000
C_IWT = C_IWT_INTER_POCK/1000

CT_IWT=(T_IWT_UNI_SAIL+T_IWT_UNI_LOCK+T_IWT_UNI_PORT+T_IWT_PRE_DRIVE+T_IWT_PRE_CONG+T_IWT_POST_DRIVE+T_IWT_POST_CONG)*1.12/1000
CT_ROAD=(T_ROAD_DRIVE+T_ROAD_CONG)*1.12/1000
CT_RAIL=(T_RAIL_UNI_DRIVE+T_RAIL_PRE_DRIVE+T_RAIL_PRE_CONG+T_RAIL_POST_DRIVE+T_RAIL_POST_CONG)*1.12/1000

V0 = ASC_IWT + B_COST_INTER_RND * C_IWT + B_FREQ * FREQ_IWT + B_ACCESS_INTER * (ACCESS_IWT_O+ACCESS_IWT_D) + B_PORT * PORTFLOWS 
V1 = ASC_ROAD + B_COST_ROAD * C_ROAD + B_ACCESS_ROAD * (ACCESS_ROAD_O+ACCESS_ROAD_D)
V2 = ASC_RAIL + B_COST_INTER_RND * C_RAIL + B_FREQ * FREQ_RAIL + B_ACCESS_INTER * (ACCESS_RAIL_O+ACCESS_RAIL_D)

V = {0: V0 ,
1: V1 ,
2: V2}

av = {0: AV_IWT ,
1: AV_ROAD ,
2: AV_RAIL }

prob = models.logit(V, av , MODE)
logprob = log(MonteCarlo(prob))*V2017
biogeme = bio.BIOGEME(database, logprob, numberOfDraws=10000)
biogeme.modelName = 'LOGN_COSTinter'

results = biogeme.estimate()
pandasResults = results.getEstimatedParameters()
print(pandasResults)

